@@ -6,7 +6,7 @@ This file is part of minos framework.
 Minos framework can not be copied and/or distributed without the express permission of Clariteia SL.
 """
 
-__version__ = "0.0.2"
+__version__ = "0.0.3"
 
 from .configuration import (
     BROKER,
@@ -24,6 +24,7 @@ from .configuration import (
 from .exceptions import (
     EmptyMinosModelSequenceException,
     MinosAttributeValidationException,
+    MinosConfigDefaultAlreadySetException,
     MinosConfigException,
     MinosException,
     MinosImportException,
@@ -33,11 +34,19 @@ from .exceptions import (
     MinosModelException,
     MinosParseAttributeException,
     MinosProtocolException,
+    MinosRepositoryAggregateNotFoundException,
+    MinosRepositoryDeletedAggregateException,
+    MinosRepositoryException,
+    MinosRepositoryManuallySetAggregateIdException,
+    MinosRepositoryManuallySetAggregateVersionException,
+    MinosRepositoryNonProvidedException,
+    MinosRepositoryUnknownActionException,
     MinosReqAttributeException,
     MinosTypeAttributeException,
     MultiTypeMinosModelSequenceException,
 )
 from .importlib import (
+    classname,
     import_module,
 )
 from .messages import (
@@ -73,6 +82,7 @@ from .model import (
     TIME_MILLIS,
     TIMESTAMP_MILLIS,
     UUID,
+    Aggregate,
     Decimal,
     Enum,
     Fixed,
@@ -86,6 +96,13 @@ from .protocol import (
     MinosAvroValuesDatabase,
     MinosBinaryProtocol,
 )
+from .repository import (
+    MinosInMemoryRepository,
+    MinosRepository,
+    MinosRepositoryAction,
+    MinosRepositoryEntry,
+    PostgreSqlMinosRepository,
+)
 from .storage import (
     MinosStorage,
     MinosStorageLmdb,
